<?php
/**
* 2007-2023 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2023 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/
class ReciboPagosConfirmationModuleFrontController extends ModuleFrontController
{
    public function postProcess()
    {
        try{
            $order_id = $_GET['cart'];
            if($order_id && (int)$order_id > 0){
                $cart = new Cart((int)$order_id);
                $customer = new Customer((int) $cart->id_customer);
                $order = Order::getByCartId($cart->id);
                if ($order->current_state == Configuration::get('PS_OS_PAYMENT')) {
                    Tools::redirectLink('order-confirmation.php?key='.$customer->secure_key.'&id_cart='.(int)$cart->id.'&id_module=recibopagos&id_order='.(int)$order_id);
                }
                else {
                    Tools::redirect('index.php?controller=order&step=1');
                }
            }
            else {
                return $this->displayError('Ha ocurrido un error inesperado en la vuelta de pago');
            }
        }
        catch(PrestaShopException $e) {
            PrestaShopLogger::addLog('ReciboPagos: Error en la vuelta de pago : '. $e,
                        3,
                        null,
                        'validation',
                        1);
            
            return $this->displayError($e);
        }
        
        
    }

    protected function displayError($message, $description = false)
    {
        array_push($this->errors, $this->module->l($message), $description);

        return $this->setTemplate('module:recibopagos/views/templates/front/error.tpl');
    }
}
