<?php
/**
* 2007-2023 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2023 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/
class ReciboPagosRedirectModuleFrontController extends ModuleFrontController
{
    /**
     * Do whatever you have to before redirecting the customer on the website of your payment processor.
     */
    public function postProcess()
    {
        /*
         * Oops, an error occured.
         */
        try{
            $cart = $this->context->cart;
            $customer = $this->context->customer;

            $order_description = 'Compra en tienda';

            $postData = [
                'merchant_order_id' => $cart->id,
                'order_description' => $order_description,
                'client_email'      => $customer->email,
                'notification_url'  => $this->context->link->getModuleLink('recibopagos', 'validation', array(), true),
                'return_url'        => $this->context->link->getModuleLink('recibopagos', 'confirmation', array(), true).'?cart='.$cart->id,
                'currencies[CLP]'   => number_format($cart->getOrderTotal(), 0, '',''),
                'created_by' => 'prestashop',
            ];
            $ch = curl_init();

            curl_setopt_array($ch, array(
                CURLOPT_URL => 'https://api.recibopagos.com/api/orders',
                CURLOPT_RETURNTRANSFER => true,
                CURLOPT_ENCODING => '',
                CURLOPT_MAXREDIRS => 10,
                CURLOPT_TIMEOUT => 0,
                CURLOPT_FOLLOWLOCATION => true,
                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
                CURLOPT_CUSTOMREQUEST => 'POST',
                CURLOPT_POSTFIELDS => $postData,
                CURLOPT_HTTPHEADER => array(
                    'Authorization: Bearer '.Configuration::get('RECIBOPAGOS_ACCOUNT_TOKEN'),

                ),
            ));


            $response = curl_exec($ch);
            $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
            curl_close($ch);

            if ($httpCode == 200) {
                $responseData = json_decode($response, true);
                Tools::redirect($responseData['checkout_url']);
            } else {
                return $this->displayError($response);
            }
        }
        catch (PrestaShopException $e) {
            PrestaShopLogger::addLog('ReciboPagos: error al intentar obtener el servicio: '. $e,
                        3,
                        null,
                        'Redirect',
                        $cart->id);
            return $this->displayError($e);
        }
        
        catch (Exception $e) {

            PrestaShopLogger::addLog('ReciboPagos: error al intentar obtener el servicio: '. $e,
                        3,
                        null,
                        'Redirect',
                        $cart->id);
            return $this->displayError($e);
        }
        
    }

    protected function displayError($message, $description = false)
    {
        array_push($this->errors, $this->module->l($message), $description);

        return $this->setTemplate('module:recibopagos/views/templates/front/error.tpl');
    }
}
