<?php
/**
* 2007-2023 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2023 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/
class ReciboPagosValidationModuleFrontController extends ModuleFrontController
{
    public function postProcess()
    {
        if ($this->module->active == false) {
            die;
        }

        $jsonData = json_decode(Tools::file_get_contents('php://input'), true);
        if (!$jsonData) {
            header('HTTP/1.1 205 Error en lectura respuesta recibopagos');
        }

        try {
            $status = $jsonData['status'];    
            $returnStatus = 'HTTP/1.1 201 Anulado';

            $cart = new Cart((int)$jsonData['merchant_order_id']);
            $customer = new Customer((int) $cart->id_customer);
            $orderId = $jsonData['merchant_order_id'];

            


            if ($status === "paid") {
                $order = $this->module->validateOrder(
                    $orderId,
                    Configuration::get('PS_OS_PAYMENT'),
                    $cart->getOrderTotal(true, Cart::BOTH),
                    $this->module->displayName,
                    $jsonData['message'], 
                    array(),
                    null,
                    true,
                    $customer->secure_key
                );
                $messageDetails = "Detalles del pago recibido:\n";
                $messageDetails .= "Método de pago: " . $jsonData['payment_method'] . "\n";
                $messageDetails .= "Monto pagado: " . $jsonData['paid_amount'] . "\n";
                $messageDetails .= "Moneda: " . $jsonData['paid_currency'] . "\n";
                $messageDetails .= "Mensaje: " . $jsonData['message'] . "\n";
                PrestaShopLogger::addLog('ReciboPagos: Pago Correcto Orden '.$orderId.' : '. $messageDetails,
                            1,
                            null,
                            'validation',
                            $orderId);
                $returnStatus = 'HTTP/1.1 200 OK';

            } else {
                PrestaShopLogger::addLog('ReciboPagos: Error en Pago Orden '.$orderId.' : '. $jsonData['message'],
                            3,
                            null,
                            'validation',
                            $orderId);
            }

            header($returnStatus);
            exit;
        }
        catch(PrestaShopException $e) {
            PrestaShopLogger::addLog('ReciboPagos: Error en Pago Orden : '. $e,
                        3,
                        null,
                        'validation',
                        1);
            header('HTTP/1.1 204 Anulado Error Desconocido');
            exit;
        }
        exit;
    }
}
